%define anolis_release 3

Name:           vmaf
Version:        2.3.1
Release:        %{anolis_release}%{?dist}
Summary:        Video Multi-Method Assessment Fusion

License:        BSD-2-Clause-Patent
URL:            https://github.com/netflix/vmaf
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz

# This project relies on AVX
ExclusiveArch:  x86_64 loongarch64 riscv64

BuildRequires:  gcc-c++
BuildRequires:  meson
BuildRequires:  nasm
BuildRequires:  vim-common

# Enforce our own build version for library
Requires:       libvmaf = %{version}-%{release}

%description
VMAF is a perceptual video quality assessment algorithm developed by
Netflix. VMAF Development Kit (VDK) is a software package that contains
the VMAF algorithm implementation, as well as a set of tools that allows
a user to train and test a custom VMAF model. For an overview, read this
tech blog post, or this slide deck.

https://github.com/Netflix/vmaf/blob/master/resource/doc/VMAF_ICIP17.pdf

%package -n     libvmaf
Summary:        Library for %{name}
Provides:       bundled(libsvm) = 3.24
Provides:       %{name}-static = %{version}-%{release}
Obsoletes:      %{name}-static < %{version}-%{release}

%description -n libvmaf
Library for %{name}.

%package -n     libvmaf-devel
Summary:        Development files for %{name}
Requires:       libvmaf = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %{name}-devel < %{version}-%{release}

%description -n libvmaf-devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        models
Summary:        Model files for %{name}
Requires:       libvmaf = %{version}-%{release}

%description    models
The %{name}-models package contains model files.
These are needed for apps that can't use the builtin models.

%package        doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1
# Unbundle
rm -rf third_party/

%build
pushd libvmaf
%meson \
 -Ddefault_library=shared
%meson_build
popd

%install
pushd libvmaf
%meson_install
popd

mkdir -p %{buildroot}%{rpmmacrodir}
cat > %{buildroot}%{rpmmacrodir}/macros.%{name} << EOF
%libvmaf_version %{version}
EOF
touch -r LICENSE %{buildroot}%{rpmmacrodir}/macros.%{name}

mkdir -p %{buildroot}%{_datadir}/model/
cp -Rp model/* %{buildroot}%{_datadir}/model/

%generate_compatibility_deps

%check
pushd libvmaf
ninja -vC %{_vpath_builddir} test ||:
popd

%files
%{_bindir}/vmaf

%files models
%{_datadir}/model/

%files -n libvmaf
%license LICENSE
%{_libdir}/*.so.1*
%dir %{abidir}
%{abidir}/libvmaf.dump

%files -n libvmaf-devel
%{rpmmacrodir}/macros.%{name}
%{_includedir}/libvmaf/
%{_libdir}/*.so
%{_libdir}/pkgconfig/libvmaf.pc

%files doc
%doc README.md
%doc CHANGELOG.md
%doc CONTRIBUTING.md

%changelog
* Tue May 06 2025 Shangtong Guo <guo.shangtong@zte.com.cn> - 2.3.1-3
- adapt for riscv64

* Mon Sep 25 2023 Wenlong Zhang <zhangwenlong@loongson.cn> - 2.3.1-2
- Add loongarch64 support

* Tue Mar 21 2023 Yuanhong Peng <yummypeng@linux.alibaba.com> - 2.3.1-1
- Init from upstream
